require 'spec_helper'

RSpec.describe Frigate::Operation::Base do

	context 'action:update' do
		class UserUpdate < Frigate::Operation::Base
			model User
			action :update
			property :email, validates: { presence: true }
		end

		let(:params) { { email: 'johndoe@gmail.com' } }
		let(:invalid_params) { {} }

		context '.run' do
			before(:example) do
				@user = User.create(email: 'smth@email.coms')
			end
			it 'updates user' do
				UserUpdate.run(params.merge({ id: @user.id }))
				user = User.first
				expect(user.email).to eq(params[:email])
			end
			context 'raises' do
				it 'params invalid error' do
					expect {
						UserUpdate.run(invalid_params.merge({ id: @user.id }))
					}.to raise_error(Frigate::Operation::InvalidParamsError)
				end
			end
		end
	end

	context 'action:create' do
		class UserCreate < Frigate::Operation::Base
			model User
			action :create
			property :email, validates: { presence: true }
		end

		let(:params) { { email: 'johndoe@gmail.com' } }

		context '.run' do
			it 'creates user' do
				UserCreate.run(params)
				user = User.first
				expect(user.email).to eq(params[:email])
			end
		end
	end

end